==> sockjs-0.0.1.tgz: package/lib/trans-htmlfile.js <==
(function() {
  var HtmlFileReceiver, iframe_template, transport, utils;
  var __hasProp = Object.prototype.hasOwnProperty, __extends = function(child, parent) {
    for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; }
    function ctor() { this.constructor = child; }
    ctor.prototype = parent.prototype;
    child.prototype = new ctor;
    child.__super__ = parent.prototype;
    return child;
  };
  utils = require('./utils');
  transport = require('./transport');
  iframe_template = "<html><head>\n  <meta http-equiv=\"X-UA-Compatible\" content=\"IE=edge\" />\n  <meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\" />\n  <script>\n    document.domain = document.domain;\n  </script>\n</head><body><h2>Don't panic!</h2>\n  <script>\n    function p(d){\n        // Sniff!\n        if (d[0] === 'c') {\n            document.body.onload = null;\n        }\n        parent.{{ callback }}(d);\n    };\n    document.body.onload = function() {p('c[1006, \"Html iframe connection broken\"]');};\n  </script>";
  iframe_template += Array(1024 - iframe_template.length).join(' ');
  iframe_template += '\r\n\r\n';
  HtmlFileReceiver = (function() {
    __extends(HtmlFileReceiver, transport.ResponseReceiver);
    function HtmlFileReceiver() {
      HtmlFileReceiver.__super__.constructor.apply(this, arguments);
    }
    HtmlFileReceiver.prototype.protocol = "htmlfile";
    HtmlFileReceiver.prototype.doSendFrame = function(payload) {
      return HtmlFileReceiver.__super__.doSendFrame.call(this, '<script>p(' + JSON.stringify(payload) + ');</script>\r\n');
    };
    return HtmlFileReceiver;
  })();
  exports.app = {
    htmlfile: function(req, res) {
      var callback, session;
      if (!('c' in req.query || 'callback' in req.query)) {
        throw {
          status: 500,
          message: '"callback" parameter required'
        };
      }
      callback = 'c' in req.query ? req.query['c'] : req.query['callback'];
      res.setHeader('Content-Type', 'text/html; charset=UTF-8');
      res.writeHead(200);
      res.write(iframe_template.replace(/{{ callback }}/g, callback));
      session = transport.Session.bySessionIdOrNew(req.session, req.sockjs_server);
      session.register(new HtmlFileReceiver(res));
      return true;
    }
  };
}).call(this);

==> sockjs-0.0.4.tgz: package/lib/trans-htmlfile.js <==
(function() {
  var HtmlFileReceiver, iframe_template, transport, utils;
  var __hasProp = Object.prototype.hasOwnProperty, __extends = function(child, parent) {
    for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; }
    function ctor() { this.constructor = child; }
    ctor.prototype = parent.prototype;
    child.prototype = new ctor;
    child.__super__ = parent.prototype;
    return child;
  };
  utils = require('./utils');
  transport = require('./transport');
  iframe_template = "<!doctype html>\n<html><head>\n  <meta http-equiv=\"X-UA-Compatible\" content=\"IE=edge\" />\n  <meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\" />\n</head><body><h2>Don't panic!</h2>\n  <script>\n    document.domain = document.domain;\n    var c = parent.{{ callback }};\n    c.start();\n    function p(d) {c.message(d);};\n    window.onload = function() {c.stop();};\n  </script>";
  iframe_template += Array(1024 - iframe_template.length).join(' ');
  iframe_template += '\r\n\r\n';
  HtmlFileReceiver = (function() {
    __extends(HtmlFileReceiver, transport.ResponseReceiver);
    function HtmlFileReceiver() {
      HtmlFileReceiver.__super__.constructor.apply(this, arguments);
    }
    HtmlFileReceiver.prototype.protocol = "htmlfile";
    HtmlFileReceiver.prototype.max_response_size = 128 * 1024;
    HtmlFileReceiver.prototype.doSendFrame = function(payload) {
      return HtmlFileReceiver.__super__.doSendFrame.call(this, '<script>\np(' + JSON.stringify(payload) + ');\n</script>\r\n');
    };
    return HtmlFileReceiver;
  })();
  exports.app = {
    htmlfile: function(req, res) {
      var callback, session;
      if (!('c' in req.query || 'callback' in req.query)) {
        throw {
          status: 500,
          message: '"callback" parameter required'
        };
      }
      callback = 'c' in req.query ? req.query['c'] : req.query['callback'];
      res.setHeader('Content-Type', 'text/html; charset=UTF-8');
      res.writeHead(200);
      res.write(iframe_template.replace(/{{ callback }}/g, callback));
      session = transport.Session.bySessionIdOrNew(req.session, req.sockjs_server);
      session.register(new HtmlFileReceiver(res));
      return true;
    }
  };
}).call(this);
